@@ -13,7 +13,7 @@ subtype 'ScopeMode',
 
 =head1 NAME
 
-TaskPipe::Role::MooseType_ScopeMode
+TaskPipe::Role::MooseType_ScopeMode - scope mode type constraint
 
 =head1 DESCRIPTION
 
