@@ -13,7 +13,7 @@ subtype 'UserAgentType',
 
 =head1 NAME
 
-TaskPipe::Role::MooseType_UserAgentType
+TaskPipe::Role::MooseType_UserAgentType - user agent type type constraint
 
 =head1 DESCRIPTION
 
