@@ -28,7 +28,7 @@ __PACKAGE__->set_primary_key("id", "job_id");
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Global::Result::Thread
+TaskPipe::SchemaTemplate_Global::Result::Thread - global schema template for C<thread> source
 
 =head1 DESCRIPTION
 
